/**
 * Pyx4me framework
 * Copyright (C) 2006-2008 pyx4j.com.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 * @author francisdb
 * @version $Id: WtkRunMojo.java 2105 2008-07-08 15:25:35Z vlads $
 */
package com.pyx4me.maven.j2me;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;

import de.pleumann.antenna.WtkRun;

/**
 * 
 * <p>
 * You can start the application in the WTK emulator. Antenna library is used
 * for this task.
 * </p>
 * 
 * @goal run
 * @phase package
 * @description Run JAD/JAR in the WTK emulator
 * 
 */
public class WtkRunMojo extends WtkJadMojo {

    /**
     * The device (skin) to use during emulation. See the antenna wtkrun task
     * for a list of supported devices
     * 
     * @parameter expression="${j2me.device}" default-value="DefaultColorPhone"
     */
    protected String device;

    public void execute() throws MojoExecutionException, MojoFailureException {
        executeRun(this, classifier, false, device);
    }

    public void executeRun(AbstractJadWtkMojo mojo, String packageClassifier, boolean isTest, String device)
            throws MojoExecutionException, MojoFailureException {
        if (mojo.wtkHome != null) {
            WtkRun task = runWtkJad(mojo, packageClassifier, isTest, device);
            mojo.executeTask(task);
        } else {
            throw new MojoFailureException("Running is only available for wtk builds");
        }
    }

    protected WtkRun runWtkJad(AbstractJadWtkMojo mojo, String packageClassifier, boolean isTest, String device)
            throws MojoExecutionException, MojoFailureException {

        WtkRun task = new WtkRun();
        mojo.initTask(task);

        task.setDevice(device);
        setFileValue(task, "setJadFile", mojo.getJadFile(packageClassifier));
        return task;
    }

}
